==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/user/messages/sv/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '<strong>Konto</strong> registrering',
  '<strong>Change</strong> Password' => '<strong>Ändra</strong> lösenord',
  '<strong>Change</strong> your password' => '<strong>Ändra</strong> ditt lösenord',
  '<strong>Join</strong> the network' => '<strong>Gå med i</strong> nätverket',
  '<strong>Password</strong> changed!' => '<strong>Lösenordet</strong> har ändrats!',
  '<strong>Password</strong> recovery' => '<strong>Lösenordsåterställning</strong>Lösenordsåterställning',
  '<strong>Password</strong> recovery!' => '<strong>Lösenordsåterställning!</strong>',
  '<strong>Please</strong> sign in' => '<strong>Var vänlig</strong> och logga in',
  '<strong>Registration</strong> successful!' => '<strong>Registrering</strong> lyckades!',
  '<strong>Sign</strong> up' => '<strong>Bli</strong> medlem',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Ditt konto</strong> har skapats!',
  'Account' => 'Konto',
  'After activating your account by the administrator, you will receive a notification by email.' => 'När en administratör har aktiverat ditt konto kommer du bli meddelad via e-post.',
  'Back' => 'Tillbaka',
  'Change password' => 'Ändra lösenord',
  'Confirm' => 'Bekräfta',
  'Create Account' => 'Skapa konto',
  'Create account' => 'Skapa konto',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Har du inget konto än? Gå med i nätverket genom att ange din e-postadress.',
  'Due to security reasons you are required to change your password in order to access the platform.' => 'Av säkerhetsskäl behöver du ändra ditt lösenord för att komma åt plattformen.',
  'Enter security code above' => 'Skriv in säkerhetskoden ovanför',
  'Forgot your password?' => 'Glömt ditt lösenord?',
  'Go to login page' => 'Gå till inloggningssidan',
  'Group' => 'Grupp',
  'Hello {displayName}' => 'Hej {displayName}',
  'Hello {displayName},' => 'Hej {displayName},',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Om du inte använder länken inom 24 timmar kommer den sluta fungera.',
  'If you\'re already a member, please login with your username/email and password.' => 'Om du redan är en medlem, logga in med ditt användarnamn/e-postadress och lösenord.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Skriv in din e-postadress så skickar vi återställningsinstruktioner!',
  'Log out' => 'Logga ut',
  'Login' => 'Logga In',
  'New user needs approval' => 'Ny användare behöver godkännande',
  'Password recovery' => 'Lösenordsåterställning',
  'Password reset' => 'Lösenordet återställt',
  'Please check your email and follow the instructions!' => 'Vänligen kontrollera din e-post och följ instruktionerna!',
  'Please click on the link below to view request:' => 'Klicka på nedanstående länk för att granska begäran:',
  'Please enter the letters from the image.' => 'Fyll i bokstäverna du ser i bilden.',
  'Please login with your username/email and password.' => 'Logga in med ditt användarnamn/e-postadress och lösenord.',
  'Please use the following link within the next day to reset your password.' => 'Använd följande länk inom en dag för att återställa ditt lösenord.',
  'Please wait' => 'Vänligen vänta',
  'Register' => 'Registrera',
  'Registration successful' => 'Registrering lyckades',
  'Remember me' => 'Kom i håg mig',
  'Reset Password' => 'Återställ lösenord',
  'Reset password' => 'Återställ lösenord',
  'Sign in' => 'Logga in',
  'To log in with your new account, click the button below.' => 'För att logga in med ditt nya konto, klicka på knappen nedan.',
  'User or Password incorrect.' => 'Användare eller lösenord var felaktigt.',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Vi har skickat ett e-postmeddelande med en länk som möjliggör för dig att återställa ditt lösenord.',
  'Your email' => 'Din e-Post',
  'Your password' => 'Ditt lösenord',
  'Your password has been successfully changed!' => 'Ditt lösenord har ändrats!',
  'Your password is incorrect!' => 'Ditt lösenord är felaktigt!',
  'a new user {displayName} needs approval.' => 'en ny användare {displayName} behöver godkännande.',
  'back to home' => 'tillbaka till förstasidan',
  'email' => 'e-post',
  'password' => 'lösenord',
  'username or email' => 'användarnamn eller e-post',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/sv/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '<strong>Konto</strong> registrering',
  '<strong>Change</strong> Password' => '<strong>Ändra</strong> lösenord',
  '<strong>Change</strong> your password' => '<strong>Ändra</strong> ditt lösenord',
  '<strong>Join</strong> the network' => '<strong>Gå med i</strong> forumet',
  '<strong>Password</strong> changed!' => '<strong>Lösenordet</strong> har ändrats!',
  '<strong>Password</strong> recovery' => '<strong>Lösenordsåterställning</strong>Lösenordsåterställning',
  '<strong>Password</strong> recovery!' => '<strong>Lösenordsåterställning!</strong>',
  '<strong>Please</strong> sign in' => '<strong>Var vänlig</strong> och logga in',
  '<strong>Registration</strong> successful!' => '<strong>Registrering</strong> lyckades!',
  '<strong>Sign</strong> up' => '<strong>Bli</strong> medlem',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Ditt konto</strong> har skapats!',
  'Account' => 'Konto',
  'After activating your account by the administrator, you will receive a notification by email.' => 'När en administratör har aktiverat ditt konto kommer du bli meddelad via e-post.',
  'Back' => 'Tillbaka',
  'Change password' => 'Ändra lösenord',
  'Confirm' => 'Bekräfta',
  'Create Account' => 'Skapa konto',
  'Create account' => 'Skapa konto',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Har du inget konto än? Gå med i forumet genom att ange din e-postadress.',
  'Due to security reasons you are required to change your password in order to access the platform.' => 'Av säkerhetsskäl behöver du ändra ditt lösenord för att komma åt plattformen.',
  'Enter security code above' => 'Skriv in säkerhetskoden ovanför',
  'Forgot your password?' => 'Glömt ditt lösenord?',
  'Go to login page' => 'Gå till inloggningssidan',
  'Group' => 'Grupp',
  'Hello {displayName}' => 'Hej {displayName}',
  'Hello {displayName},' => 'Hej {displayName},',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Om du inte använder länken inom 24 timmar kommer den sluta fungera.',
  'If you\'re already a member, please login with your username/email and password.' => 'Om du redan är en medlem, logga in med ditt användarnamn/e-postadress och lösenord.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Skriv in din e-postadress så skickar vi återställningsinstruktioner!',
  'Log out' => 'Logga ut',
  'Login' => 'Logga In',
  'New user needs approval' => 'Ny användare behöver godkännande',
  'Password recovery' => 'Lösenordsåterställning',
  'Password reset' => 'Lösenordet återställt',
  'Please check your email and follow the instructions!' => 'Vänligen kontrollera din e-post och följ instruktionerna!',
  'Please click on the link below to view request:' => 'Klicka på nedanstående länk för att granska begäran:',
  'Please enter the letters from the image.' => 'Fyll i bokstäverna du ser i bilden.',
  'Please login with your username/email and password.' => 'Logga in med ditt användarnamn/e-postadress och lösenord.',
  'Please use the following link within the next day to reset your password.' => 'Använd följande länk inom en dag för att återställa ditt lösenord.',
  'Please wait' => 'Vänligen vänta',
  'Register' => 'Registrera',
  'Registration successful' => 'Registrering lyckades',
  'Remember me' => 'Kom i håg mig',
  'Reset Password' => 'Återställ lösenord',
  'Reset password' => 'Återställ lösenord',
  'Sign in' => 'Logga in',
  'To log in with your new account, click the button below.' => 'För att logga in med ditt nya konto, klicka på knappen nedan.',
  'User or Password incorrect.' => 'Användare eller lösenord var felaktigt.',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Vi har skickat ett e-postmeddelande med en länk som möjliggör för dig att återställa ditt lösenord.',
  'Your email' => 'Din e-Post',
  'Your password' => 'Ditt lösenord',
  'Your password has been successfully changed!' => 'Ditt lösenord har ändrats!',
  'Your password is incorrect!' => 'Ditt lösenord är felaktigt!',
  'a new user {displayName} needs approval.' => 'en ny användare {displayName} behöver godkännande.',
  'back to home' => 'tillbaka till förstasidan',
  'email' => 'e-post',
  'password' => 'lösenord',
  'username or email' => 'användarnamn eller e-post',
);
